@@ -14,12 +14,15 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION     = version->new('0.5.7');
+our $VERSION     = version->new('0.5.8');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 #our @EXPORT      = qw//;
 
 sub args {
+    return (
+        'path|p=s',
+    );
 }
 
 sub default {
@@ -86,7 +89,7 @@ App::TemplateCMD::Command - The base class for command modules
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command version 0.5.7.
+This documentation refers to App::TemplateCMD::Command version 0.5.8.
 
 =head1 SYNOPSIS
 
